@@ -36,8 +36,8 @@ class client(Thread):
         while self.running:
             with contextlib.suppress(socket.timeout):
                 data = self.socket.recv(6525)
-                logger.info(
-                    f"NODE:{self.server.host}:{self.server.port} SOCK:{self.host}:{self.port} Received data {data}"
+                logger.debug(
+                    f"NODE:{self.server.host}:{self.server.port} SOCK:{self.host}:{self.port} Received data"
                 )
                 data = data.decode("utf-8")
                 with contextlib.suppress(json.decoder.JSONDecodeError):
